#!/usr/bin/env node
const fs = require('fs');
const { execSync } = require('child_process');

const modelIndex = `import fs from 'fs';
import path from 'path';
import Sequelize from 'sequelize';
import configJson from '../config/config';

const basename = path.basename(__filename);
const env = process.env.NODE_ENV ? process.env.NODE_ENV : 'development';
const config = configJson[env];

console.log('this is the environment: ', env);

const db = {};

let sequelize;
if (config.environment === 'production') {
  sequelize = new Sequelize(process.env[config.use_env_variable], config);
  sequelize = new Sequelize(
    process.env.DB_NAME,
    process.env.DB_USER,
    process.env.DB_PASS,
    {
      host: process.env.DB_HOST,
      port: process.env.DB_PORT,
      dialect: 'postgres',
      dialectOption: {
        ssl: true,
        native: true
      },
      logging: true
    }
  );
} else {
  sequelize = new Sequelize(
    config.database,
    config.username,
    config.password,
    config
  );
}

fs.readdirSync(__dirname)
  .filter(
    (file) => file.indexOf('.') !== 0 && file !== basename && file.slice(-3) === '.js'
  )
  .forEach((file) => {
    const model = require(path.join(__dirname, file))(
      sequelize,
      Sequelize.DataTypes
    );
    db[model.name] = model;
  });

Object.keys(db).forEach((modelName) => {
  if (db[modelName].associate) {
    db[modelName].associate(db);
  }
});

db.sequelize = sequelize;
db.Sequelize = Sequelize;

export default db;
`;


const stdin = process.openStdin();
process.stdout.write('Please Enter Your NodeJS Application Name: ');
stdin.addListener('data', text => {
  const appName = text.toString().trim();
  if (appName) {
    const config = `require('dotenv').config();
    
module.exports = {
  development: {
    database: '${appName}',
    username: 'postgres',
    password: null,
    host: '127.0.0.1',
    dialect: 'postgres'
  },

  test: {
    database: '${appName}_test',
    username: 'postgres',
    password: null,
    host: '127.0.0.1',
    dialect: 'postgres'
  },

  production: {
    database: '${appName}_prod',
    username: 'postgres',
    password: null,
    host: '127.0.0.1',
    dialect: 'postgres'
  }
};`;
    if (!fs.existsSync(`./${appName}`)){
      fs.mkdirSync(`./${appName}`);
    }
  
    const dirs = [
      `./${appName}/api`,
      `./${appName}/api/account`,
      `./${appName}/api/account/controllers`,
      `./${appName}/api/account/routes`,
      `./${appName}/api/account/services`,
      `./${appName}/api/account/validations`,
      `./${appName}/api/admin`,
      `./${appName}/api/admin/controllers`,
      `./${appName}/api/admin/routes`,
      `./${appName}/api/admin/services`,
      `./${appName}/api/admin/validations`,
      `./${appName}/api/mail`,
      `./${appName}/api/private`,
      `./${appName}/api/private/controllers`,
      `./${appName}/api/private/routes`,
      `./${appName}/api/private/services`,
      `./${appName}/api/private/validations`,
      `./${appName}/api/src`,
      `./${appName}/api/src/config`,
      `./${appName}/api/test`,
      `./${appName}/api/utils`,
      `./${appName}/api/config`,
    ];
  
    const files = [
      '/.babelrc',
      '/.dockerignore',
      '/.env',
      '/.eslintignore',
      '/.eslintrc.js',
      '/.gitignore',
      '/.sequelizerc',
      '/docker-compose.yml',
      '/DockerFile',
      '/package.json',
      '/api/index.js',
      '/api/index.js',
      '/api/account/index.js',
      '/api/admin/index.js',
      '/api/private/index.js',
      '/api/utils/helpers.js',
      '/api/utils/utils.js',
      '/api/config/settings.js',
    ];
  
    console.clear();
    for (let i = 0; i < dirs.length; i++) {
      if (!fs.existsSync(dirs[i])){
        fs.mkdirSync(dirs[i]);
      }
    }
    for (let j = 0; j < files.length; j++) {
      fs.copyFile(`${process.env.APPDATA.replace(/\\/g, "/")}/npm/node_modules/mdp-cli/nodejs/${files[j]}`, `./${appName}/${files[j]}`, (err) => {
        if (err) throw err;
      });
    }
  
    process.chdir(`${process.cwd().replace(/\\/g, "/")}/${appName}`);
      
    console.log('Files is ready.');
    console.log('Please Wait... Npm install command is running for you...');
    execSync('npm install');
    console.log('sequelize init is running...')
    execSync('npx sequelize init');
    
    const changeFile = [
      './package.json',
      './api/config/settings.js',
      './docker-compose.yml',
    ];

    for (let k = 0; k < changeFile.length; k++) {
      var data = fs.readFileSync(changeFile[k], 'utf-8');
      var newValue = data.split('app_title').join(appName);
      fs.writeFileSync(changeFile[k], newValue, 'utf-8');
    }
    
    fs.writeFileSync('./api/src/models/index.js', modelIndex, 'utf-8');
    fs.writeFileSync('./api/src/config/config.js', config, 'utf-8');

    console.log(`${appName} application is created succesfully. Happy Hacking!`);
    console.log('- BSevinc');
  }
  stdin.pause();
});
