import React, { Component } from 'react';
import { HashRouter } from 'react-router-dom';
import PropTypes from 'prop-types';
import { connect } from 'react-redux';
import { bindActionCreators } from 'redux';
import { createStructuredSelector } from 'reselect';
import Routes from './commons/routes';
import { GlobalStyle } from './assets/styled';
import Toast from './commons/Toast';

import { setToast  } from './store/actions';
import { selectToast } from './store/selectors';

class App extends Component {
  constructor(props) {
    super(props);
    this.state = {
    };
  }

  render() {
    return (
      <HashRouter>
        <Toast
          isOpen={this.props.toast.open}
          message={this.props.toast.message}
          handleClose={() => this.props.setToast(false)}
          variant={this.props.toast.variant}
        />
        <div className="mainContent">
          <Routes />
        </div>
        <GlobalStyle />
      </HashRouter>
    );
  }
}

App.propTypes = {
  toast: PropTypes.object.isRequired,
  setToast: PropTypes.func.isRequired,
};

// App.defaultProps = {
//   toast: '',
// };

const mapStateToProps = createStructuredSelector({
  toast: selectToast(),
});

const mapDispatchToProps = (dispatch) => (
  (
    bindActionCreators({
      setToast,
    }, dispatch)
  )
);

export default connect(mapStateToProps, mapDispatchToProps)(App);
