// import FormData from 'form-data';

export const request = (url, method, data = false, authorization = false) => {
  const headers = {
    'Content-Type': 'application/json',
  };
  if (authorization) {
    const token = localStorage.getItem('token');
    if (token) {
      headers.authorization = localStorage.getItem('token');
    }
  }
  const options = {
    headers,
    method,
  };

  if (data) {
    options.body = data;
  }
  return fetch(url, options)
    .then((response) => {
      if (!response.ok) {
        throw Error(response.statusText);
      }
      return response;
    })
    .then((response) => response.json())
    .catch(() => 'invalid');
};

export const filesRequest = (url, method, data = false, file) => {
  const myHeaders = new Headers();
  myHeaders.append('Authorization', localStorage.getItem('token'));

  const formdata = new FormData();
  formdata.append('file', file);
  formdata.append('isCreated', data);

  const requestOptions = {
    method,
    headers: myHeaders,
    body: formdata,
    redirect: 'follow',
  };

  return fetch(url, requestOptions)
    .then((response) => {
      if (!response.ok) {
        throw Error(response.statusText);
      }
      return response;
    })
    .then((response) => response.json())
    .catch(() => 'invalid');
};

const saveAs = (blob, fileName) => {
  const url = window.URL.createObjectURL(blob);
  const anchorElem = document.createElement('a');
  anchorElem.style = 'display: none';
  anchorElem.href = url;
  anchorElem.download = fileName;
  document.body.appendChild(anchorElem);
  anchorElem.click();
  document.body.removeChild(anchorElem);
  setTimeout(() => {
    window.URL.revokeObjectURL(url);
  }, 1000);
};

export const fileDownload = (url, method, data = false) => {
  const headers = {
    authorization: localStorage.getItem('token'),
    responseType: 'arraybuffer',
  };
  const options = {
    headers,
    method,
  };
  if (data) {
    options.body = data;
  }
  fetch(url, options)
    .then((res) => res.blob())
    .then((blob) => {
      const fileName = 'export.xlsx';
      saveAs(blob, fileName);
    });
};
