#!/usr/bin/env node

const stdin = process.openStdin();
process.stdout.write('Please Enter Your React Application Name: ');
stdin.addListener('data', text => {
  const appName = text.toString().trim();
  if (appName) {
    console.clear();
    const fs = require('fs');
    const { execSync } = require('child_process');

    const pJson = `{
      "name": "${appName}",
      "version": "0.1.0",
      "private": true,
      "dependencies": {
        "@date-io/date-fns": "^1.3.13",
        "@material-ui/core": "^4.11.0",
        "@material-ui/icons": "^4.9.1",
        "@material-ui/lab": "^4.0.0-alpha.56",
        "@material-ui/pickers": "^3.2.10",
        "@testing-library/jest-dom": "^4.2.4",
        "@testing-library/react": "^9.5.0",
        "@testing-library/user-event": "^7.2.1",
        "date-fns": "^2.15.0",
        "eslint-config-airbnb": "^18.2.0",
        "eslint-plugin-import": "^2.22.0",
        "eslint-plugin-jsx-a11y": "^6.3.1",
        "eslint-plugin-react": "^7.20.3",
        "prop-types": "^15.7.2",
        "react": "^16.13.1",
        "react-dom": "^16.13.1",
        "react-redux": "^7.2.1",
        "react-router-dom": "^5.2.0",
        "react-scripts": "^3.4.1",
        "redux": "^4.0.5",
        "redux-saga": "^1.1.3",
        "reselect": "^4.0.0",
        "styled-components": "^5.1.1"
      },
      "devDependencies": {
        "eslint": "^6.6.0",
        "eslint-config-airbnb": "^17.1.0",
        "eslint-plugin-import": "^2.14.0",
        "eslint-plugin-jsx-a11y": "^6.1.1",
        "eslint-plugin-react": "^7.11.0"
      },
      "scripts": {
        "start": "react-scripts start",
        "build": "react-scripts build",
        "test": "react-scripts test",
        "eject": "react-scripts eject"
      },
      "eslintConfig": {
        "extends": "react-app"
      },
      "browserslist": {
        "production": [
          ">0.2%",
          "not dead",
          "not op_mini all"
        ],
        "development": [
          "last 1 chrome version",
          "last 1 firefox version",
          "last 1 safari version"
        ]
      }
    }`;
    
    if (!fs.existsSync(`./${appName}`)){
      fs.mkdirSync(`./${appName}`);
    }
    
    var createStream = fs.createWriteStream(`./${appName}/package.json`);
    createStream.end();
    fs.writeFileSync(`./${appName}/package.json`, pJson, 'utf-8');
    
    const dirs = [
      `./${appName}/public`,
      `./${appName}/src`,
      `./${appName}/src/assets`,
      `./${appName}/src/commons`,
      `./${appName}/src/components`,
      `./${appName}/src/pages`,
      `./${appName}/src/assets/fonts`,
      `./${appName}/src/assets/img`,
      `./${appName}/src/store`,
    ];
    
    const files = [
      '/src/assets/statics.js',
      '/src/assets/styled.js',
      '/src/commons/constants.js',
      '/src/commons/routes.js',
      '/src/commons/Toast.js',
      '/src/commons/utils.js',
      '/src/store/actions.js',
      '/src/store/constants.js',
      '/src/store/reducers.js',
      '/src/store/sagas.js',
      '/src/store/selectors.js',
      '/src/pages/Dashboard.js',
      '/src/.eslintrc.js',
      '/src/App.js',
      '/src/index.js',
      '/src/serviceWorker.js',
      '/public/index.html',
      '/public/manifest.json',
      '/public/robots.txt',
      '/public/favicon.ico',
    ];
    console.clear();
    
    for (let i = 0; i < dirs.length; i++) {
      if (!fs.existsSync(dirs[i])){
        fs.mkdirSync(dirs[i]);
      }
    }
    for (let j = 0; j < files.length; j++) {
      fs.copyFile(`${process.env.APPDATA.replace(/\\/g, "/")}/npm/node_modules/mdp-cli/react/${files[j]}`, `./${appName}/${files[j]}`, (err) => {
        if (err) throw err;
      });
    }
    
    process.chdir(`${process.cwd().replace(/\\/g, "/")}/${appName}`);
    
    console.log('Files is ready.');
    console.log('Please Wait... Npm install command is running for you...');
    execSync('npm install');
    
    var data = fs.readFileSync('./public/index.html', 'utf-8');
    var newValue = data.replace('app_title', appName);
    fs.writeFileSync('./public/index.html', newValue, 'utf-8');
    var data = fs.readFileSync('./src/pages/Dashboard.js', 'utf-8');
    var newValue = data.replace('app_title', appName);
    fs.writeFileSync('./src/pages/Dashboard.js', newValue, 'utf-8');
    
    console.log(`${appName} application is created succesfully. Happy Hacking!`);
    console.log('- BSevinc');
  }
  stdin.pause();
});
